.. _tutorial:

================
 SymPy Tutorial
================

.. toctree::
   :maxdepth: 2

   preliminaries.rst
   intro.rst
   gotchas.rst
   basic_operations.rst
   printing.rst
   simplification.rst
   calculus.rst
   solvers.rst
   matrices.rst
   manipulation.rst
